<?php
/**
 * Plugin Name: Srmehran Templates
 * Description: Import hundreds of free & Premium Professionally designed, code-free & fully flexible Full-page or block templates 
 * Author:      Srmehran Templates
 * Version:     0.4
 * Author URI:  https://srmehranclub.com
 * Text Domain: srmehnraclub-dashboard
 * Domain Path: includes/languages/
 * Network:     true
 * WDP ID:      119
 *
 * @package SRMEHRAN_Templtes
 */
 require_once 'includes/Class-Base-Elementor-Editor.php';
 add_filter( 'plugin_row_meta', 'wk_plugin_row_meta', 10, 2 );

function wk_plugin_row_meta( $links, $file ) {    
    if ( plugin_basename( __FILE__ ) == $file ) {
        $row_meta = array(
          'officialssite'    => '<a href="' . esc_url( 'https://srmehranclub.com/' ) . '" target="_blank" aria-label="' . esc_attr__( 'Plugin Additional Links', 'domain' ) . '" style="color:green;">' . esc_html__( 'Officials site', 'domain' ) . '</a>',
		  'support'    => '<a href="' . esc_url( 'https://srmehranclub.com/contact-us/' ) . '" target="_blank" aria-label="' . esc_attr__( 'Plugin Additional Links', 'domain' ) . '" style="color:green;">' . esc_html__( 'Need support ?', 'domain' ) . '</a>'
        );

        return array_merge( $links, $row_meta );
    }
    return (array) $links;
}

 
class SRMEHRAN_Templtes extends BaseElementor{

	/**
	 * The current plugin version. Must match the plugin header.
	 *
	 * @var string (Version number)
	 */
	static public $version = '0.1';

	/**
	 * Holds the API module.
	 * Handles all the remote calls to the SRMEHRAN Server.
	 *
	 * @var   SRMEHRAN_Template_Post_Request_Handler
	 * @since 4.0.0
	 */
	static $api_handel = null;

	/**
	 * Holds the Remote module.
	 * Handles all the Hub calls from the SRMEHRAN Servers.
	 *
	 * @var   SRMEHRAN_Templtes_Remote
	 * @since 4.0.0
	 */
	static $remote = null;

	/**
	 * Holds the Site/Settings module.
	 * Handles all local things like storing/fetching settings.
	 *
	 * @var   SRMEHRAN_Templtes_Site
	 * @since 4.0.0
	 */
	static $template_site_info = null;

	/**
	 * Holds the UI module.
	 * Handles all the UI tasks, like displaying a specific Dashboard page.
	 *
	 * @var   SRMEHRAN_Templtes_Ui
	 * @since 4.0.0
	 */
	static $template_ui = null;

	/**
	 * Holds the Upgrader module.
	 * Handles all upgrade/installation relevant tasks.
	 *
	 * @var   SRMEHRAN_Templtes_Upgrader
	 * @since 4.1.0
	 */
	static $upgrader = null;

	/**
	 * Holds the Notification module.
	 * Handles all the dashboard notifications.
	 *
	 * @var   SRMEHRAN_Templtes_Notice
	 * @since 4.0.0
	 */
	static $notice = null;

	static $register_url;
	static $Plugin_url_path;
	static $api_ajax;

/**
	 * Creates and returns the SRMEHRAN Dashboard object.
	 * We'll have only one of those ;)
	 *
	 * Important: This function must be called BEFORE the plugins_loaded hook!
	 *
	 * @since  4.0.0
	 * @return SRMEHRAN_Templtes
	 */
	static public function instance() {
		static $Inst = null;

		if ( null === $Inst ) {
			$Inst =new SRMEHRAN_Templtes();
		}

		return $Inst;
	}

		/**
	 * The singleton constructor will initialize the modules.
	 *
	 * Important: This function must be called BEFORE the plugins_loaded hook!
	 *
	 * @since 1.0.0
	 */
	private function __construct() {
		
		// This is for the outer Elementor editor, we need JS to add our magic button and register onclick events etc..
		add_action( 'elementor/element/after_section_end', array( $this, 'enqueue_editor_scripts_smrahn_template' ) );
		// This is for the inner iframe, we only need CSS in this inner iframe:
		add_action( 'elementor/preview/enqueue_styles', [ $this, 'enqueue_embedded_iframe_styles' ] );
		
		require_once 'includes/class-template-site-info.php';
		require_once 'includes/class-remote-site-template.php';
		require_once 'includes/class-template-backend-ui.php';
		require_once 'includes/class-api.php';
		
		
		self::$template_site_info     = new SRMEHRAN_Template_Site_Info( __FILE__ );
		self::$api_handel      = new SRMEHRAN_Template_Post_Request_Handler();
		self::$api_ajax      = new SrmehranApi();
		self::$template_ui = new SRMEHRAN_Template_Admin_Ui();
		self::$register_url = "https://srmehranclub.com/my-account/";
		self::$Plugin_url_path = trailingslashit( plugins_url( '', __FILE__ ) );
		
	}

	
	/**
	 * Load JS for our custom Elementor modal.
	 */
	public function enqueue_editor_scripts_smrahn_template() {

		// Now load our custom elementor_modal.js code and css:
		wp_enqueue_script( 'smrhan_module_elementor',SRMEHRAN_Templtes::$template_site_info->plugin_url . 'js/smrhan_module_elementor.js?v1.2', array( 'jquery' ));
		
	}

	public function enqueue_embedded_iframe_styles(){
		
			wp_enqueue_style(
			'elementor-add-srmehran-template-button',
			SRMEHRAN_Templtes::$template_site_info->plugin_url . 'css/elementor-add-srmehran-template-button.css',
			array()
		);
	}


}

// Initialize the SRMEHRAN Dashboard.
SRMEHRAN_Templtes::instance();


// On Plugin Activate
register_activation_hook(__FILE__, 'template_db_plugin_activation');


function template_db_plugin_activation(){
	 global $wpdb;

    require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
    dbDelta("CREATE TABLE IF NOT EXISTS `" . $wpdb->prefix . "templates_download_history` (
        `id` bigint(21) unsigned NOT NULL AUTO_INCREMENT,
        `type` VARCHAR(255) DEFAULT '' NOT NULL ,
        `action` VARCHAR(255) DEFAULT '' NOT NULL,
        `date` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ,
        `post_id` VARCHAR(30) NOT NULL ,
        `template_id` VARCHAR(30) NOT NULL ,
        PRIMARY KEY (`id`),
        UNIQUE KEY `id` (`id`)
    ) ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1");


}


// On Plugin DeActivate
register_deactivation_hook(__FILE__, 'template_db_plugin_deactivation');
function template_db_plugin_deactivation() {

	add_action( 'init', 'template_db_plugin_action_deactivation' );

}


function template_db_plugin_action_deactivation() {
delete_option('srmehran_Templtes_ss_credentials_username');
		delete_option('srmehran_Templtes_ss_credentials_password');
	///plugin logout and  decactvate function here 
}




add_action( 'elementor/init', 'register_custom_remote_source' );

/**
 * Basically Replace Default Remote source with a custom one.
 */
function register_custom_remote_source() {
	// Deregister the default remote source first. Not sure that this is particularly needed but better be safe than sorry.
	\Elementor\Plugin::instance()->templates_manager->unregister_source( 'remote' );

	// Then include your own source which will have the "remote" id.
	\Elementor\Plugin::instance()->templates_manager->register_source( 'Elementor\TemplateLibrary\Custom_Remote_Source' );
}